@@ -9,20 +9,9 @@ HitachiTV1::HitachiTV1(
       Hitachi_Make,
       index)
 {
-  NECProtocol *np = new NECProtocol(
-    guiObject,
-    index,
-    600, 500,
-    600, 1600,
-    40000, false);
+  threadableProtocol = new NECProtocol(guiObject, index);
 
-  threadableProtocol = np;
-
-  np->setHeaderPair(9000, 4500);
-  np->setTrailerPulse(600);
-  np->setRepeatPair(9000, 2250);
-
-  np->setPreData(0x0AF5, 16);
+  setPreData(0x0AF5, 16);
 
   addKey("1", One_Key, 0xB04F, 16);
   addKey("2", Two_Key, 0x708F, 16);
@@ -158,20 +147,9 @@ HitachiProjector::HitachiProjector(
       Hitachi_Make,
       index)
 {
-  NECProtocol *np = new NECProtocol(
-    guiObject,
-    index,
-    600, 500,
-    600, 1600,
-    108000, true);
+  threadableProtocol = new NECProtocol(guiObject, index);
 
-  threadableProtocol = np;
-
-  np->setHeaderPair(9000, 4500);
-  np->setTrailerPulse(600);
-  np->setRepeatPair(9000, 2250);
-
-  np->setPreData(0xE1A2, 16);
+  setPreData(0xE1A2, 16);
 
   addKey("Power", Power_Key, 0xE817, 16);
   addKey("PageUp", Unmapped_Key, 0x0BF4, 16);
@@ -210,20 +188,9 @@ HitachiDVD1::HitachiDVD1(
       Hitachi_Make,
       index)
 {
-  NECProtocol *np = new NECProtocol(
-    guiObject,
-    index,
-    600, 500
-    600, 1600,
-    108000, true);
+  threadableProtocol = new NECProtocol(guiObject, index);
 
-  threadableProtocol = np;
-
-  np->setHeaderPair(9000, 4500);
-  np->setTrailerPulse(600);
-  np->setRepeatPair(9000, 2250);
-
-  np->setPreData(0x01C4, 16);
+  setPreData(0x01C4, 16);
 
   addKey("Power", Power_Key, 0x50AF, 16);
   addKey("Surround", Surround_Key, 0xBA45, 16);
@@ -280,20 +247,9 @@ HitachiAudio1::HitachiAudio1(
   addControlledDevice(Hitachi_Make, "FX-7", Audio_Device);
   addControlledDevice(Hitachi_Make, "FX-77", Audio_Device);
 
-  NECProtocol *np = new NECProtocol(
-    guiObject,
-    index,
-    600, 500,
-    600, 1600,
-    108000, true);
+  threadableProtocol = new NECProtocol(guiObject, index);
 
-  threadableProtocol = np;
-
-  np->setHeaderPair(9000, 4500);
-  np->setTrailerPulse(600);
-  np->setRepeatPair(9000, 2250);
-
-  np->setPreData(0xDA25, 16);
+  setPreData(0xDA25, 16);
 
   addKey("1", One_Key, 0xB24D, 16);
   addKey("2", Two_Key, 0x728D, 16);
@@ -325,3 +281,63 @@ HitachiAudio1::HitachiAudio1(
   addKey("TUNER_BAND", Input_Key, 0xE01F, 16);
   addKey("POWER", Power_Key, 0x00FF, 16);
 }
+
+
+HitachiVCR1::HitachiVCR1(
+  QObject *guiObject,
+  unsigned int index)
+  : PIRKeysetMetaData(
+      "VCR Keyset 1",
+      Hitachi_Make,
+      index)
+{
+  threadableProtocol = new NECProtocol(guiObject, index);
+
+  setPreData(0x06F9, 16);
+
+  addKey("Power", Power_Key, 0xE817, 16);
+  addKey("Eject", Eject_Key, 0x9C63, 16);
+  addKey("VCR/TV", Input_Key, 0x6897, 16);
+  addKey("P+", ChannelUp_Key, 0x9867, 16);
+  addKey("P-", ChannelDown_Key, 0x18E7, 16);
+  addKey("Play", Play_Key, 0x28D7, 16);
+  addKey("FF", FastForward_Key, 0x906F, 16);
+  addKey("Rew", Rewind_Key, 0x50AF, 16);
+  addKey("Stop", Stop_Key, 0xD02F, 16);
+  addKey("Pause", Pause_Key, 0x58A7, 16);
+  addKey("Step", StepForward_Key, 0x08F7, 16);
+  addKey("SpinRight", Right_Key, 0xFE01, 16);
+  addKey("SpinLeft", Left_Key, 0x7E81, 16);
+  addKey("Enter", Select_Key, 0x22DD, 16);
+  addKey("TransAux", Unmapped_Key, 0x2CD3, 16); // "AVX"
+  addKey("1", One_Key, 0xB04F, 16);
+  addKey("2", Two_Key, 0x708F, 16);
+  addKey("3", Three_Key, 0xF00F, 16);
+  addKey("4", Four_Key, 0x38C7, 16);
+  addKey("5", Five_Key, 0xB847, 16);
+  addKey("6", Six_Key, 0x7887, 16);
+  addKey("7", Seven_Key, 0xF807, 16);
+  addKey("8", Eight_Key, 0x20DF, 16);
+  addKey("9", Nine_Key, 0xA05F, 16);
+  addKey("0", Zero_Key, 0x30CF, 16);
+  addKey("Menu", Menu_Key, 0x02FD, 16);
+  addKey("Disp", Info_Key, 0x42BD, 16);
+  addKey("Index", Unmapped_Key, 0xA25D, 16);
+  addKey("SP/LP", VHSSpeed_Key, 0x0CF3, 16);
+  addKey("Count/Clock", Unmapped_Key, 0x629D, 16);
+  addKey("CLEAR", Reset_Key, 0x827D, 16); // "reset", "0000"
+  addKey("Slow", Unmapped_Key, 0x8877, 16);
+  addKey("CH1/2", Unmapped_Key, 0xA857, 16); // "CHANNEL"
+  addKey("A.DUB", Unmapped_Key, 0x34CB, 16);
+  addKey("V.DUB", Unmapped_Key, 0x5CA3, 16);
+  addKey("Tracking+", TrackingPlus_Key, 0x00FF, 16);
+  addKey("Tracking-", TrackingMinus_Key, 0x807F, 16);
+  addKey("100/ENT", PlusOneHundred_Key, 0x609F, 16);
+  addKey("-", Unmapped_Key, 0xC03F, 16);
+  addKey("+", Unmapped_Key, 0x40BF, 16);
+  addKey("GO-TO", Unmapped_Key, 0x619E, 16);
+  addKey("FRAME+", Unmapped_Key, 0xBE41, 16); // This is for jog/shuttle!
+  addKey("FRAME-", Unmapped_Key, 0x7E81, 16); // I'll get the other j/s later
+  // For more Jog/Shuttle see LIRC hitachi/VT-RM783E
+  addKey("tracking_auto", AutoTracking_Key, 0x7C83, 16);
+}
