@@ -23,7 +23,7 @@ MagnavoxDVD1::MagnavoxDVD1(
 
   rp->setToggleBit(5);
 
-  rp->setPreData(0xEFB, 13);
+  setPreData(0xEFB, 13);
 
   addKey("power", Power_Key, 0xF3, 8);
   addKey("1", One_Key, 0xFE, 8);
@@ -203,10 +203,10 @@ MagnavoxTV1::MagnavoxTV1(
 
   threadableProtocol = rp;
 
-  rp->setPreData(0x10, 5);
-
   rp->setToggleBit(2);
 
+  setPreData(0x10, 5);
+
   addKey("Power", Power_Key, 0x0C, 8);
   addKey("Reset", Reset_Key, 0x0E, 8);
   addKey("Sleep", Sleep_Key, 0x26, 8);
