@@ -298,6 +298,10 @@ private slots:
 private:
   void enableButtons();
 
+  void startRepeating(
+    unsigned int id,
+    PIRKeyName name);
+
   void stopRepeating();
 
   void populateFavorites();
@@ -316,9 +320,4 @@ private:
 };
 
 
-inline void MainWindow::stopRepeating()
-{
-  myKeysets->stopRepeating();
-}
-
 #endif // MAINWINDOW_H
