@@ -4,15 +4,18 @@ PIRMakeMgr::PIRMakeMgr()
 {
   makes[Any_Make] = "Any";
   makes[Apple_Make] = "Apple";
+  makes[Denon_Make] = "Denon";
   makes[Ei_Make] = "Ei";
   makes[GoldStar_Make] = "GoldStar";
   makes[Hauppauge_Make] = "Hauppauge";
+  makes[Hitachi_Make] = "Hitachi";
   makes[JVC_Make] = "JVC";
   makes[LG_Make] = "LG";
   makes[Mitsubishi_Make] = "Mitsubishi";
   makes[Nokia_Make] = "Nokia";
-  makes[Philips_Make] = "Philips";
   makes[Panasonic_Make] = "Panasonic";
+  makes[Philips_Make] = "Philips";
+  makes[Pinnacle_Make] = "Pinnacle Systems";
   makes[Raite_Make] = "Raite";
   makes[RCA_Make] = "RCA";
   makes[Sagem_Make] = "Sagem";
