@@ -8,15 +8,18 @@
 enum PIRMakeName{
   Any_Make,
   Apple_Make,
+  Denon_Make,
   Ei_Make,
   GoldStar_Make,
   Hauppauge_Make,
+  Hitachi_Make,
   JVC_Make,
   LG_Make,
   Mitsubishi_Make,
   Nokia_Make,
   Panasonic_Make,
   Philips_Make,
+  Pinnacle_Make,
   Raite_Make,
   RCA_Make,
   Sagem_Make,
